
#include "adxl362_spi_drv.h"
#include "nrf_drv_spi.h"
#include "boards.h"
#include "app_util_platform.h"

static const nrf_drv_spi_t * p_spi_master;
static const nrf_drv_spi_config_t adxl362_spi_config =
{
    .irq_priority = APP_IRQ_PRIORITY_LOW,
    .orc          = 0xCC,
    .frequency    = NRF_DRV_SPI_FREQ_1M,
    .mode         = NRF_DRV_SPI_MODE_0,		// CPOL = 0, CPHA = 0
    .bit_order    = NRF_DRV_SPI_BIT_ORDER_MSB_FIRST,
	.mosi_pin = SPIM0_MOSI_PIN,
	.ss_pin   = SPIM0_SS_PIN,
	.miso_pin = SPIM0_MISO_PIN,
	.sck_pin  = SPIM0_SCK_PIN,
};

/**@brief Function for initializing the ADXL362 SPI driver.
 *
 * @param[in] nrf_drv_spi_t * m_spi_master    Pointer to spi instance to use with ADXL362
 *
 */
void adxl362_spi_srv_init(const nrf_drv_spi_t * m_spi_master)
{
	p_spi_master = m_spi_master;

	// Initialize the SPI instance to use with ADXL362 accelerometer
	APP_ERROR_CHECK( nrf_drv_spi_init(m_spi_master, &adxl362_spi_config, NULL) ); // No event handler, SPI will be in blocking mode
}

/**@brief Function for reading ADXL362's registers over SPI.
 *
 * @param[in] address   ADXL362 Register address
 * @param[in] p_data    Pointer to rx buffer
 * @param[in] bytes     Number of bytes to be read
 *
 */
void adxl362_spi_drv_readRegister(uint8_t address, uint8_t * p_data, uint8_t bytes)
{
	uint32_t err_code;

	//Prepare tx_buffer
	uint8_t tx_buffer[2];
	tx_buffer[0] = ADXL362_READ_REG_CMD;
	tx_buffer[1] = address;

	// Pull Chip Select line low
	nrf_gpio_pin_clear(adxl362_spi_config.ss_pin);

	err_code = nrf_drv_spi_transfer(p_spi_master, tx_buffer, sizeof(tx_buffer), p_data, bytes);

	// Set Chipselect line high
	nrf_gpio_pin_set(adxl362_spi_config.ss_pin);

	APP_ERROR_CHECK(err_code);

}
